@@ -5,16 +5,19 @@
 
 import os
 import sys
-import shutil
 import fnmatch
 import logging
 
+if sys.version > '3':
+    basestring = str
+
 from jinja2 import Environment, ChoiceLoader, FileSystemLoader
 
+from .builders import static_builder, template_builder
 from .helpers import lazy_property
 
 __all__ = ['Folio']
-__version__ = '0.3'
+__version__ = '0.4'
 
 
 class Folio(object):
@@ -48,6 +51,9 @@ class Folio(object):
         'TESTING':                              False,
         'EXTENSIONS':                           [],
         'JINJA_EXTENSIONS':                     [],
+
+        'STATIC_BUILDER_PATTERN':               '*',
+        'TEMPLATE_BUILDER_PATTERN':             '*.html',
     }
 
     def __init__(self, import_name, source_path='src', build_path='build',
@@ -58,9 +64,6 @@ class Folio(object):
         #: debugging information.
         self.import_name = import_name
 
-        #: The project logger, an instance of the :class: `logging.Logger`.
-        self.logger = logging.getLogger(self.import_name)
-
         #: Make the configuration dictionary.
         self.config = self._create_config()
         self.config_initialized = False
@@ -109,7 +112,7 @@ class Folio(object):
         #: The default builder is given, this will treat all HTML files as
         #: jinja2 templates and process them, generating the same template name
         #: as output file in the build directory.
-        self.builders = [('*', _static_builder), ('*.html', _template_builder)]
+        self.builders = []
 
         #: The jinja environment is used to make a list of the templates, and
         #: it's used by the builders to dump output files.
@@ -134,6 +137,21 @@ class Folio(object):
             return os.path.abspath(os.path.dirname(module.__file__))
         return os.getcwd()
 
+    @lazy_property
+    def logger(self):
+        """The project logger, an instance of the :class: `logging.Logger`.
+
+        The default configuration is to log to stderr if the application is
+        in debug mode.
+        """
+        logger = logging.getLogger(self.import_name)
+
+        if self.config['DEBUG']:
+            logger.setLevel(logging.DEBUG)
+            logger.addHandler(logging.StreamHandler())
+
+        return logger
+
     def _make_abspath(self, path):
         """Make a path absolute. If the given path is relative, it will be
         from the root path of the project.
@@ -157,6 +175,12 @@ class Folio(object):
         if self.config_initialized:
             return
 
+        if not self.builders:
+            self.add_builder(self.config['STATIC_BUILDER_PATTERN'],
+                             static_builder)
+            self.add_builder(self.config['TEMPLATE_BUILDER_PATTERN'],
+                             template_builder)
+
         # Register extensions.
         for extension in self.config.get('EXTENSIONS', []):
             self.register_extension(extension)
@@ -355,6 +379,12 @@ class Folio(object):
         if not callable(builder):
             raise TypeError('Invalid builder. Must be a callable.')
         if isinstance(pattern, basestring):
+            try:
+                enabled = builder.enabled
+            except AttributeError:
+                enabled = True
+            if not enabled:
+                self.logger.warning('Builder %s disabled', repr(builder))
             self.builders.append((pattern, builder))
         else:
             try:
@@ -372,7 +402,12 @@ class Folio(object):
         """
         for pattern, builder in reversed(self.builders):
             if fnmatch.fnmatch(template_name, pattern):
-                return builder
+                try:
+                    enabled = builder.enabled
+                except AttributeError:
+                    enabled = True
+                if enabled:
+                    return builder
         return None
 
     def translate_template_name(self, template_name):
@@ -470,12 +505,3 @@ class Folio(object):
             self.add_context(pattern, func)
             return func
         return wrapper
-
-
-def _static_builder(env, template_name, context, src, dst, encoding):
-    shutil.copy(src, dst)
-
-
-def _template_builder(env, template_name, context, src, dst, encoding):
-    template = env.get_template(template_name)
-    template.stream(**context).dump(dst, encoding=encoding)
